@@ -18,14 +18,20 @@
 bal_accuracy <- function(data, ...) {
   UseMethod("bal_accuracy")
 }
-
-class(bal_accuracy) <- c("class_metric", "function")
-attr(bal_accuracy, "direction") <- "maximize"
+bal_accuracy <- new_class_metric(
+  bal_accuracy,
+  direction = "maximize"
+)
 
 #' @export
 #' @rdname bal_accuracy
-bal_accuracy.data.frame <- function(data, truth, estimate,
-                                    estimator = NULL, na_rm = TRUE, ...) {
+bal_accuracy.data.frame <- function(data,
+                                    truth,
+                                    estimate,
+                                    estimator = NULL,
+                                    na_rm = TRUE,
+                                    event_level = yardstick_event_level(),
+                                    ...) {
 
   metric_summarizer(
     metric_nm = "bal_accuracy",
@@ -35,49 +41,53 @@ bal_accuracy.data.frame <- function(data, truth, estimate,
     estimate = !!enquo(estimate),
     estimator = estimator,
     na_rm = na_rm,
+    event_level = event_level,
     ... = ...
   )
 
 }
 
 #' @export
-bal_accuracy.table <- function(data, estimator = NULL, ...) {
-
+bal_accuracy.table <- function(data,
+                               estimator = NULL,
+                               event_level = yardstick_event_level(),
+                               ...) {
   check_table(data)
   estimator <- finalize_estimator(data, estimator)
 
   metric_tibbler(
     .metric = "bal_accuracy",
     .estimator = estimator,
-    .estimate = bal_accuracy_table_impl(data, estimator)
+    .estimate = bal_accuracy_table_impl(data, estimator, event_level)
   )
-
 }
 
 #' @export
-bal_accuracy.matrix <- function(data, estimator = NULL, ...) {
-
+bal_accuracy.matrix <- function(data,
+                                estimator = NULL,
+                                event_level = yardstick_event_level(),
+                                ...) {
   data <- as.table(data)
-  bal_accuracy.table(data, estimator)
-
+  bal_accuracy.table(data, estimator, event_level)
 }
 
 #' @export
 #' @rdname bal_accuracy
-bal_accuracy_vec <- function(truth, estimate, estimator = NULL,
-                             na_rm = TRUE, ...) {
-
+bal_accuracy_vec <- function(truth,
+                             estimate,
+                             estimator = NULL,
+                             na_rm = TRUE,
+                             event_level = yardstick_event_level(),
+                             ...) {
   estimator <- finalize_estimator(truth, estimator)
 
   bal_accuracy_impl <- function(truth, estimate) {
-
     xtab <- vec2table(
       truth = truth,
       estimate = estimate
     )
 
-    bal_accuracy_table_impl(xtab, estimator)
-
+    bal_accuracy_table_impl(xtab, estimator, event_level)
   }
 
   metric_vec_template(
@@ -89,26 +99,21 @@ bal_accuracy_vec <- function(truth, estimate, estimator = NULL,
     cls = "factor",
     ...
   )
-
 }
 
-bal_accuracy_table_impl <- function(data, estimator) {
-
+bal_accuracy_table_impl <- function(data, estimator, event_level) {
   if(is_binary(estimator)) {
-    bal_accuracy_binary(data)
+    bal_accuracy_binary(data, event_level)
   } else {
     w <- get_weights(data, estimator)
     out_vec <- bal_accuracy_multiclass(data, estimator)
     weighted.mean(out_vec, w)
   }
-
 }
 
-bal_accuracy_binary <- function(data) {
-
+bal_accuracy_binary <- function(data, event_level) {
   # (sens + spec) / 2
-  ( recall_binary(data) + spec_binary(data) ) / 2
-
+  ( recall_binary(data, event_level) + spec_binary(data, event_level) ) / 2
 }
 
 # Urbanowicz 2015 ExSTraCS 2.0 description and evaluation of a scalable learning.pdf
