@@ -12,6 +12,13 @@
 #'
 #' `rsq()` is simply the squared correlation between `truth` and `estimate`.
 #'
+#' Because `rsq()` internally computes a correlation, if either `truth` or
+#' `estimate` are constant it can result in a divide by zero error. In these
+#' cases, a warning is thrown and `NA` is returned. This can occur when a model
+#' predicts a single value for all samples. For example, a regularized model
+#' that eliminates all predictors except for the intercept would do this.
+#' Another example would be a CART model that contains no splits.
+#'
 #' @family numeric metrics
 #' @family consistency metrics
 #' @templateVar metric_fn rsq
@@ -35,14 +42,20 @@
 #' rsq(solubility_test, solubility, randomized)
 #' rsq_trad(solubility_test, solubility, randomized)
 #'
+#' # A constant `truth` or `estimate` vector results in a warning from
+#' # a divide by zero error in the correlation calculation.
+#' # `NA` will be returned in these cases.
+#' truth <- c(1, 2)
+#' estimate <- c(1, 1)
+#' rsq_vec(truth, estimate)
 #' @export
-#'
 rsq <- function(data, ...) {
   UseMethod("rsq")
 }
-
-class(rsq) <- c("numeric_metric", "function")
-attr(rsq, "direction") <- "maximize"
+rsq <- new_numeric_metric(
+  rsq,
+  direction = "maximize"
+)
 
 #' @rdname rsq
 #' @export
