@@ -17,9 +17,9 @@ context("PR Curve/AUC")
 # names(sk_pr_curve) <- c("precision", "recall", "thresholds")
 # yardstick:::auc(sk_pr_curve$recall, sk_pr_curve$precision)
 
-pr_val <- 0.946446700643149
+test_that('Two class PR AUC', {
+  pr_val <- 0.946446700643149
 
-test_that('PR AUC', {
   expect_equal(
     pr_auc(two_class_example, truth = "truth", "Class1")[[".estimate"]],
     pr_val
@@ -30,21 +30,33 @@ test_that('PR AUC', {
   )
 })
 
+test_that("`event_level = 'second'` works", {
+  df <- two_class_example
+
+  df_rev <- df
+  df_rev$truth <- relevel(df_rev$truth, "Class2")
+
+  expect_equal(
+    pr_auc_vec(df$truth, df$Class1),
+    pr_auc_vec(df_rev$truth, df_rev$Class1, event_level = "second")
+  )
+})
+
 # ------------------------------------------------------------------------------
 
-# Known PR Curve result
-pr_example <- data.frame(
-  lab   = factor(c("Yes", "Yes", "No", "Yes"), levels = c("Yes", "No")),
-  score = c(.9, .4, .35, .7)
-)
+test_that('Two class PR Curve', {
+  # Known PR Curve result
+  pr_example <- data.frame(
+    lab   = factor(c("Yes", "Yes", "No", "Yes"), levels = c("Yes", "No")),
+    score = c(.9, .4, .35, .7)
+  )
 
-pr_result <- list(
-  .threshold = c(Inf, 0.9, 0.7, 0.4, 0.35),
-  recall = c(0, 1/3, 2/3, 1, 1),
-  precision = c(1, 1, 1, 1, 0.75)
-)
+  pr_result <- list(
+    .threshold = c(Inf, 0.9, 0.7, 0.4, 0.35),
+    recall = c(0, 1/3, 2/3, 1, 1),
+    precision = c(1, 1, 1, 1, 0.75)
+  )
 
-test_that('PR Curve', {
   expect_equal(
     as.list(pr_curve(pr_example, truth = "lab", "score")),
     pr_result
@@ -53,7 +65,6 @@ test_that('PR Curve', {
 
 
 test_that('Multiclass PR Curve', {
-
   res <- pr_curve(hpc_cv, obs, VF:L)
 
   expect_equal(
@@ -69,9 +80,9 @@ test_that('Multiclass PR Curve', {
 
 # ------------------------------------------------------------------------------
 
-hpc_f1 <- data_hpc_fold1()
-
 test_that("Multiclass PR AUC", {
+  hpc_f1 <- data_hpc_fold1()
+
   expect_equal(
     pr_auc(hpc_f1, obs, VF:L, estimator = "macro")[[".estimate"]],
     prob_macro_metric(pr_auc_binary)
@@ -213,3 +224,35 @@ test_that("PR - same class prob, different prediction value", {
   )
 
 })
+
+# ------------------------------------------------------------------------------
+
+test_that("PR - zero row data frame works", {
+  df <- data.frame(y = factor(levels = c("a", "b")), x = double())
+
+  expect <- dplyr::tibble(
+    .threshold = Inf,
+    recall = 0,
+    precision = 1
+  )
+
+  class(expect) <- c("pr_df", class(expect))
+
+  expect_identical(
+    expect_warning(pr_curve(df, y, x)),
+    expect
+  )
+})
+
+test_that("PR - No `truth` gives `NaN` recall values", {
+  df <- data.frame(
+    y = factor(c("b", "b"), levels = c("a", "b")),
+    x = c(.1, .2)
+  )
+
+  expect_warning({
+    curve <- pr_curve(df, y, x)
+  })
+
+  expect_identical(curve$recall, c(0, NaN, NaN))
+})
